Documentation
¶
Overview ¶
Package cli implements Cobra CLI commands for Raven.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrWorkflowNotFound = errors.New("workflow definition not found")
ErrWorkflowNotFound is returned when a workflow definition cannot be resolved. This occurs in resume mode when T-049 built-in definitions are not yet available.
Functions ¶
func NewRootCmd ¶
NewRootCmd returns a new instance of the root command for use in external tools such as the shell completion generator and man page generator. It initialises a fresh cobra command tree with the same persistent flags and PersistentPreRunE as the global rootCmd so that generated docs and completions include all flags.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.